﻿using Hotline.Repository.SqlSugar.DataPermissions;
using Hotline.Share.Dtos;
using Hotline.Share.Tools;
using Hotline.Snapshot;
using Hotline.Snapshot.Interfaces;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using XF.Domain.Dependency;

namespace Hotline.Repository.SqlSugar.Snapshot;
public class OrderSnapshotRepository : BaseRepository<OrderSnapshot>, IOrderSnapshotRepository, IScopeDependency
{
    public OrderSnapshotRepository(ISugarUnitOfWork<HotlineDbContext> uow, IDataPermissionFilterBuilder dataPermissionFilterBuilder) : base(uow, dataPermissionFilterBuilder)
    {
    }

    public async Task<OrderSnapshot> GetByNetworkENumberAsync(string appealNumber)
    {
        return await Queryable().Where(m => m.NetworkENumber == appealNumber).FirstAsync();
    }

    /// <summary>
    /// 更新工单标签
    /// </summary>
    /// <param name="id"></param>
    /// <param name="labels"></param>
    /// <returns></returns>
    public async Task UpdateLabelAsync(string id, IList<Kv> labels)
    {
        var labelName = string.Join('|', labels.Select(m => m.Value));
        var query = Updateable()
            .SetColumns(m => m.Labels, labels)
            .SetColumns(m => m.LabelName, labelName);

        if (labels.NotNullOrEmpty())
        {
            if (labels.Any(m => m.Key == "yzg"))
                query.SetColumns(m => m.IsRectifyDepartment, true);
            if (labels.Any(m => m.Key == "wzg"))
                query.SetColumns(m => m.IsRectifyDepartment, false);
            if (labels.Any(m => m.Key == "ss"))
                query.SetColumns(m => m.IsTruthDepartment, true);
            if (labels.Any(m => m.Key == "bss"))
                query.SetColumns(m => m.IsTruthDepartment, false);
        }

        await query
            .Where(m => m.Id == id)
            .ExecuteCommandAsync();
    }
}
